@@ -5,6 +5,10 @@ class CompileError(Exception):
     def __init__(self, message):
         super().__init__(utf8text(message, 'replace'))
 
+    @property
+    def message(self) -> str:
+        return self.args[0]
+
 
 class InternalError(Exception):
     pass
@@ -12,7 +16,7 @@ class InternalError(Exception):
 
 class OutputLimitExceeded(Exception):
     def __init__(self, stream, limit):
-        super().__init__("exceeded %d-byte limit on %s stream" % (limit, stream))
+        super().__init__('exceeded %d-byte limit on %s stream' % (limit, stream))
 
 
 class InvalidCommandException(Exception):
