@@ -1,21 +1,24 @@
 import subprocess
 
+from dmoj.cptbox.filesystem_policies import ExactFile
 from dmoj.executors.compiled_executor import CompiledExecutor
 
 
 class Executor(CompiledExecutor):
     ext = 'cbl'
-    name = 'CBL'
     command = 'cobc'
     address_grace = 131072
     compile_output_index = 0
-    test_program = '''\
+    compiler_read_fs = [
+        ExactFile('/etc/gnucobol/default.conf'),
+    ]
+    test_program = """\
 	IDENTIFICATION DIVISION.
 	PROGRAM-ID. HELLO-WORLD.
 	PROCEDURE DIVISION.
 		DISPLAY 'echo: Hello, World!'.
 		STOP RUN.
-'''  # noqa: W191
+"""  # noqa: W191
 
     def get_compile_args(self):
         return [self.get_command(), '-x', '-free', self._code]
@@ -30,4 +33,4 @@ class Executor(CompiledExecutor):
         for prefix in (b'Error:', b'Note:', b'Warning:'):
             if prefix in output or prefix.lower() in output:
                 return output
-        return ''
+        return b''
