@@ -1,20 +1,20 @@
-from typing import Optional
-
 from .gcc_executor import GCCExecutor
 
 
 class Executor(GCCExecutor):
     command = 'g++'
-    std: Optional[str] = None
+    std: str = 'c++03'
     ext = 'cpp'
     test_program = """
 #include <iostream>
 
+#if __cplusplus >= 199711 && __cplusplus < 201103
 int main() {
     std::cout << std::cin.rdbuf();
     return 0;
 }
+#endif
 """
 
     def get_flags(self):
-        return (['-std=%s' % self.std] if self.std else []) + super().get_flags()
+        return ([f'-std={self.std}']) + super().get_flags()
