@@ -1,18 +1,21 @@
+from dmoj.cptbox.filesystem_policies import ExactFile
 from dmoj.executors.compiled_executor import CompiledExecutor
 
 
 class Executor(CompiledExecutor):
     ext = 'd'
-    name = 'D'
     address_grace = 32768
     command = 'dmd'
-    test_program = '''\
+    compiler_read_fs = [
+        ExactFile('/etc/dmd.conf'),
+    ]
+    test_program = """\
 import std.stdio;
 
 void main() {
     writeln(readln());
 }
-'''
+"""
     source_filename_format = 'main.{ext}'
 
     def get_compile_args(self):
