@@ -4,9 +4,7 @@ from dmoj.executors.asm_executor import NASMExecutor, PlatformX86Mixin
 class Executor(PlatformX86Mixin, NASMExecutor):
     nasm_format = 'elf32'
 
-    name = 'NASM'
-
-    test_program = '''\
+    test_program = """\
 section .text
 global  _start
 
@@ -35,4 +33,4 @@ _exit:
 
 section .bss
     buffer  resb    4096
-'''
+"""
