@@ -2,6 +2,7 @@ import os
 from subprocess import CalledProcessError, check_output
 from typing import List
 
+from dmoj.cptbox.filesystem_policies import ExactFile
 from dmoj.judgeenv import env
 from .gcc_executor import GCCExecutor
 
@@ -11,10 +12,9 @@ class Executor(GCCExecutor):
     objc_flags: List[str] = []
     objc_ldflags: List[str] = []
     command = 'gobjc'
-    name = 'OBJC'
     address_grace = 131072
 
-    test_program = r'''
+    test_program = r"""
 #import <Foundation/Foundation.h>
 
 int main (int argc, const char * argv[]) {
@@ -25,7 +25,7 @@ int main (int argc, const char * argv[]) {
     [pool drain];
     return 0;
 }
-'''
+"""
 
     def get_flags(self):
         return self.objc_flags + super().get_flags()
@@ -34,7 +34,7 @@ int main (int argc, const char * argv[]) {
         return self.objc_ldflags + super().get_ldflags()
 
     def get_fs(self):
-        return super().get_fs() + [r'/proc/\d+/cmdline$']
+        return super().get_fs() + [ExactFile('/proc/self/cmdline')]
 
     @classmethod
     def initialize(cls):
