@@ -1,11 +1,14 @@
+from dmoj.cptbox.filesystem_policies import RecursiveDir
 from dmoj.executors.compiled_executor import CompiledExecutor
 
 
 class Executor(CompiledExecutor):
     ext = 'scm'
-    name = 'SCM'
     command = 'chicken-csc'
     command_paths = ['chicken-csc', 'csc']
+    compiler_read_fs = [
+        RecursiveDir('/var/lib/chicken'),
+    ]
     test_program = '(import chicken.io) (map print (read-lines))'
 
     def get_compile_args(self):
