@@ -5,15 +5,14 @@ from dmoj.executors.script_executor import ScriptExecutor
 
 class Executor(ScriptExecutor):
     ext = 'tcl'
-    name = 'TCL'
     nproc = -1  # TCL uses a bunch of threads internally
     address_grace = 131072
     command = 'tclsh'
     syscalls = ['connect', 'access', 'getsockname']
-    test_program = '''\
+    test_program = """\
 gets stdin input
 puts $input
-'''
+"""
 
     @classmethod
     def get_runtime_versions(cls):
