@@ -1,20 +1,19 @@
-import abc
 import hashlib
 import os
 import pty
-import signal
-import subprocess
-import threading
-import time
-from typing import Callable, Dict, List, Optional
+from typing import Any, Dict, IO, List, Optional, Sequence, Tuple, Union
 
 import pylru
 
+from dmoj.cptbox import TracedPopen
+from dmoj.cptbox.compiler_isolate import CompilerIsolateTracer
+from dmoj.cptbox.filesystem_policies import FilesystemAccessRule
 from dmoj.error import CompileError, OutputLimitExceeded
+from dmoj.executors.base_executor import BaseExecutor, ExecutorMeta
 from dmoj.judgeenv import env
 from dmoj.utils.communicate import safe_communicate
+from dmoj.utils.error import print_protection_fault
 from dmoj.utils.unicode import utf8bytes
-from .base_executor import BaseExecutor
 
 
 # A lot of executors must do initialization during their constructors, which is
@@ -27,7 +26,7 @@ from .base_executor import BaseExecutor
 # Contract: if cached=True is specified and an entry exists in the cache,
 # `create_files` and `compile` will not be run, and `_executable` will be loaded
 # from the cache.
-class _CompiledExecutorMeta(abc.ABCMeta):
+class _CompiledExecutorMeta(ExecutorMeta):
     @staticmethod
     def _cleanup_cache_entry(_key, executor: 'CompiledExecutor') -> None:
         # Mark the executor as not-cached, so that if this is the very last reference
@@ -38,7 +37,7 @@ class _CompiledExecutorMeta(abc.ABCMeta):
         env.compiled_binary_cache_size, _cleanup_cache_entry
     )
 
-    def __call__(self, *args, **kwargs) -> 'CompiledExecutor':
+    def __call__(cls, *args, **kwargs) -> 'CompiledExecutor':
         is_cached: bool = kwargs.pop('cached', False)
         if is_cached:
             kwargs['dest_dir'] = env.compiled_binary_cache_dir
@@ -51,8 +50,8 @@ class _CompiledExecutorMeta(abc.ABCMeta):
         if is_cached:
             cache_key_material = utf8bytes(obj.__class__.__name__ + obj.__module__) + obj.get_binary_cache_key()
             cache_key = hashlib.sha384(cache_key_material).hexdigest()
-            if cache_key in self.compiled_binary_cache:
-                executor = self.compiled_binary_cache[cache_key]
+            if cache_key in cls.compiled_binary_cache:
+                executor = cls.compiled_binary_cache[cache_key]
                 assert executor._executable is not None
                 # Minimal sanity checking: is the file still there? If not, we'll just recompile.
                 if os.path.isfile(executor._executable):
@@ -64,54 +63,11 @@ class _CompiledExecutorMeta(abc.ABCMeta):
         obj.compile()
 
         if is_cached:
-            self.compiled_binary_cache[cache_key] = obj
+            cls.compiled_binary_cache[cache_key] = obj
 
         return obj
 
 
-class TimedPopen(subprocess.Popen):
-    def __init__(self, *args, **kwargs):
-        self._time = kwargs.pop('time_limit', None)
-        super().__init__(*args, **kwargs)
-
-        self._is_ole = False
-        self.timed_out = False
-        if self._time:
-            # Spawn thread to kill process after it times out
-            self._shocker = threading.Thread(target=self._shocker_thread)
-            self._shocker.start()
-
-    def mark_ole(self):
-        self._is_ole = True
-
-    @property
-    def is_ole(self):
-        return self._is_ole
-
-    def _shocker_thread(self) -> None:
-        # Though this shares a name with the shocker thread used for submissions, where the process shocker thread
-        # is a fine scalpel that ends a TLE process with surgical precision, this is more like a rusty hatchet
-        # that beheads a misbehaving compiler.
-        #
-        # It's not very accurate: time starts ticking in the next line, regardless of whether the process is
-        # actually running, and the time is updated in 0.25s intervals. Nonetheless, it serves the purpose of
-        # not allowing the judge to die.
-        #
-        # See <https://github.com/DMOJ/judge/issues/141>
-        start_time = time.time()
-
-        while self.returncode is None:
-            if time.time() - start_time > self._time:
-                self.timed_out = True
-                try:
-                    os.killpg(self.pid, signal.SIGKILL)
-                except OSError:
-                    # This can happen if the process exits quickly
-                    pass
-                break
-            time.sleep(0.25)
-
-
 class CompiledExecutor(BaseExecutor, metaclass=_CompiledExecutorMeta):
     executable_size = env.compiler_size_limit * 1024
     compiler_time_limit = env.compiler_time_limit
@@ -122,7 +78,14 @@ class CompiledExecutor(BaseExecutor, metaclass=_CompiledExecutorMeta):
     _executable: Optional[str] = None
     _code: Optional[str] = None
 
-    def __init__(self, problem_id: str, source_code: bytes, *args, **kwargs):
+    compiler_read_fs: Sequence[FilesystemAccessRule] = []
+    compiler_write_fs: Sequence[FilesystemAccessRule] = []
+    compiler_syscalls: Sequence[Union[str, Tuple[str, Any]]] = []
+
+    # List of directories required by the compiler to be present, typically for writing to
+    compiler_required_dirs: List[str] = []
+
+    def __init__(self, problem_id: str, source_code: bytes, *args, **kwargs) -> None:
         super().__init__(problem_id, source_code, **kwargs)
         self.warning = None
         self._executable = None
@@ -136,39 +99,27 @@ class CompiledExecutor(BaseExecutor, metaclass=_CompiledExecutorMeta):
         with open(self._code, 'wb') as fo:
             fo.write(utf8bytes(source_code))
 
+        for path in self.compiler_required_dirs:
+            path = os.path.expanduser(path)
+            try:
+                os.mkdir(path, mode=0o775)
+            except FileExistsError:
+                pass
+
     def get_compile_args(self) -> List[str]:
         raise NotImplementedError()
 
-    def get_compile_env(self) -> Optional[dict]:
+    def get_compile_env(self) -> Optional[Dict[str, str]]:
         return None
 
-    def get_compile_popen_kwargs(self) -> dict:
+    def get_compile_popen_kwargs(self) -> Dict[str, Any]:
         return {}
 
-    def create_executable_limits(self) -> Optional[Callable[[], None]]:
-        try:
-            import resource
-            from dmoj.utils.os_ext import oom_score_adj, OOM_SCORE_ADJ_MAX
+    def get_compiler_security(self):
+        sec = CompilerIsolateTracer(tmpdir=self._dir, read_fs=self.compiler_read_fs, write_fs=self.compiler_write_fs)
+        return self._add_syscalls(sec, self.compiler_syscalls)
 
-            def limit_executable():
-                os.setpgrp()
-
-                # Mark compiler process as first to die in an OOM situation, just to ensure that the judge will not
-                # be killed.
-                try:
-                    oom_score_adj(OOM_SCORE_ADJ_MAX)
-                except Exception:
-                    import traceback
-
-                    traceback.print_exc()
-
-                resource.setrlimit(resource.RLIMIT_FSIZE, (self.executable_size, self.executable_size))
-
-            return limit_executable
-        except ImportError:
-            return None
-
-    def create_compile_process(self, args: List[str]) -> TimedPopen:
+    def create_compile_process(self, args: List[str]) -> TracedPopen:
         # Some languages may insist on providing certain functionality (e.g. colored highlighting of errors) if they
         # feel they are connected to a terminal. Some are more persistent than others in enforcing this, so this hack
         # aims to provide a convincing-enough lie to the runtime so that it starts singing in color.
@@ -178,19 +129,27 @@ class CompiledExecutor(BaseExecutor, metaclass=_CompiledExecutorMeta):
         # Some runtimes *cough cough* Swift *cough cough* actually check the environment variables too.
         env = self.get_compile_env() or os.environ.copy()
         env['TERM'] = 'xterm'
+        # Instruct compilers to put their temporary files into the submission directory,
+        # so that we can allow it as writeable, rather than of all of /tmp.
+        assert self._dir is not None
+        env['TMPDIR'] = self._dir
 
-        proc = TimedPopen(
-            args,
+        proc = TracedPopen(
+            [utf8bytes(a) for a in args],
             **{
+                'executable': utf8bytes(args[0]),
+                'security': self.get_compiler_security(),
                 'stderr': _slave,
                 'stdout': _slave,
                 'stdin': _slave,
-                'cwd': self._dir,
+                'cwd': utf8bytes(self._dir),
                 'env': env,
-                'preexec_fn': self.create_executable_limits(),
-                'time_limit': self.compiler_time_limit,
+                'nproc': -1,
+                'fsize': self.executable_size,
+                'time': self.compiler_time_limit or 0,
+                'memory': 0,
                 **self.get_compile_popen_kwargs(),
-            }
+            },
         )
 
         class io_error_wrapper:
@@ -198,17 +157,17 @@ class CompiledExecutor(BaseExecutor, metaclass=_CompiledExecutorMeta):
             Wrap pty-related IO errors so that we don't crash Popen.communicate()
             """
 
-            def __init__(self, fd):
-                self.fd = fd
+            def __init__(self, io: IO) -> None:
+                self.io = io
 
             def read(self, *args, **kwargs):
                 try:
-                    return self.fd.read(*args, **kwargs)
+                    return self.io.read(*args, **kwargs)
                 except (IOError, OSError):
-                    return ''
+                    return b''
 
             def __getattr__(self, attr):
-                return getattr(self.fd, attr)
+                return getattr(self.io, attr)
 
         # Since stderr and stdout are connected to the same slave pty, proc.stderr will contain the merged stdout
         # of the process as well.
@@ -217,7 +176,7 @@ class CompiledExecutor(BaseExecutor, metaclass=_CompiledExecutorMeta):
         os.close(_slave)
         return proc
 
-    def get_compile_output(self, process: TimedPopen) -> bytes:
+    def get_compile_output(self, process: TracedPopen) -> bytes:
         # Use safe_communicate because otherwise, malicious submissions can cause a compiler
         # to output hundreds of megabytes of data as output before being killed by the time limit,
         # which effectively murders the MySQL database waiting on the site server.
@@ -228,8 +187,10 @@ class CompiledExecutor(BaseExecutor, metaclass=_CompiledExecutorMeta):
             output = b'compiler output too long (> 64kb)'
 
         if self.is_failed_compile(process):
-            if process.timed_out:
+            if process.is_tle:
                 output = b'compiler timed out (> %d seconds)' % self.compiler_time_limit
+            if process.protection_fault:
+                print_protection_fault(process.protection_fault)
             self.handle_compile_error(output)
 
         return output
@@ -237,7 +198,7 @@ class CompiledExecutor(BaseExecutor, metaclass=_CompiledExecutorMeta):
     def get_compiled_file(self) -> str:
         return self._file(self.problem)
 
-    def is_failed_compile(self, process: TimedPopen) -> bool:
+    def is_failed_compile(self, process: TracedPopen) -> bool:
         return process.returncode != 0
 
     def handle_compile_error(self, output: bytes) -> None:
