@@ -511,7 +511,7 @@ class JudgeWorker:
                 # Legacy hack: we need to allow graders to read and write `proc_output` on the `Result` object, but the
                 # judge controller only cares about the trimmed output, and shouldn't waste memory buffering the full
                 # output. So, we trim it here so we don't run out of memory in the controller.
-                result.proc_output = result.output
+                result.proc_output = utf8bytes(result.output)
                 yield IPC.RESULT, (batch_number, case_number, result)
 
             if batch_number:
